
# This file contains paths to various tools and databases used by the TC1, TC2, and ICERFIRE tools.
# the paths below are for demonstration purposes only. Please update these paths before running the tools.

# path to the IEDB T cell class I tool
tcell_class_i_path='/path_to_tc1/ng_tc1'

# path to the IEDB T cell class II tool
tcell_class_ii_path='/path_to_tc2/ng_tc2'

# The variables below this line are only necessary if you plan to use
# the ICERFIRE tool

# Path to your local copy of the IEDB PepX sqlite database.  You can
# download a copy from https://downloads.iedb.org/nextgen-tools/pepx/LATEST
pepx_db_path='/path_to_pepx/pepX-prod-20231018.indexed.sqlite'

# If using a different Python binary for ICERFIRE than for PVC and TC1, sometimes
# this requires updating the LD_LIBRARY_PATH to point to the correct libraries.  If
# using the same binary for all methods, you can leave this empty.
icerfire_python_lib_path=None

# Path to the Python 3 binary inside the virtualenv that you created for ICERFIRE.
# Generally, this will be under $VIRUALENV_PATH/bin/python3
icerfire_python_path='/path_to_venvs/icerfire/bin/python3'

# Python environment module for use with ICERFIRE (most users will
# not need to set this)
icerfire_python_module=None